#ifndef FILELIST_H
#define FILELIST_H

#include <sys/stat.h>

#ifndef GNOME_H
#include <gnome.h>
#endif

#ifndef PROTOCOL_H
#include "protocol.h"
#endif

typedef struct {
  char *name;
  int size;
  char type[5],creator[5];
  gboolean is_folder,is_selected;
} FileEntry;

typedef struct {
  Connection *c;
  GtkWidget *frame;
  GtkWidget *list;
  GtkWidget *path_menu,*path_widget;
  GtkWidget *toolbar[16];
  int numfiles;
  FileEntry **files;
  FileEntry *last_selected;
  int count_selected;
  int sortby;
  gboolean is_remote;
  int numpaths;
  char **path;
  gpointer data;
  struct _FLOps *flops;
} FileList;

typedef struct _FLOps {
  int is_remote;
  void (*change_selection)(FileList *,gpointer);
  void (*refresh)(FileList *,gpointer);
  void (*mkdir)(FileList *,char *name,gpointer);
  void (*start_transfer)(FileList *,FileEntry *which,gpointer);
  void (*delete)(FileList *,int which,gpointer);
  void (*chdir_to)(FileList *,int which,gpointer);
  void (*select_one)(FileList *,FileEntry *which,gpointer);
  void (*properties)(FileList *,FileEntry *which,gpointer);
} FLOps;

FileList *filelist_new(Connection *c,FLOps *,gpointer data);
void filelist_destroy(FileList *fl);
void filelist_clear(FileList *fl);
void filelist_set_contents(FileList *fl,int count, FileEntry **files);
void filelist_set_path(FileList *fl,char **path);
void filelist_deselect_all(gpointer dummy,FileList *fl);
void filelist_select_all(FileList *fl);
void filelist_start_transfer(FileList *fl);

FileEntry *fileentry_new_from_stat(char *name, struct stat *buf);
FileEntry *fileentry_new_from_object(HLObject *o);
void fileentry_free(FileEntry *fe);


#endif
